summaryrefslogtreecommitdiff
path: root/gtk2_ardour/ardour_dialog.h
diff options
context:
space:
mode:
authorPaul Davis <paul@linuxaudiosystems.com>2009-12-17 18:24:23 +0000
committerPaul Davis <paul@linuxaudiosystems.com>2009-12-17 18:24:23 +0000
commitf6fdd8dcbf41f864e9f0cc32dabe81fe3533ddfe (patch)
tree5214c580b9e6c17a499fa587660dbf949e892bf2 /gtk2_ardour/ardour_dialog.h
parentda762129f19c28aff64f833b6ec09fba946faef6 (diff)
switch to using boost::signals2 instead of sigc++, at least for libardour. not finished yet, but compiles, loads sessions, records and can close a session without a crash
git-svn-id: svn://localhost/ardour2/branches/3.0@6372 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'gtk2_ardour/ardour_dialog.h')
-rw-r--r--gtk2_ardour/ardour_dialog.h21
1 files changed, 7 insertions, 14 deletions
diff --git a/gtk2_ardour/ardour_dialog.h b/gtk2_ardour/ardour_dialog.h
index cd0fce4162..bd74afc47d 100644
--- a/gtk2_ardour/ardour_dialog.h
+++ b/gtk2_ardour/ardour_dialog.h
@@ -20,20 +20,23 @@
#ifndef __ardour_dialog_h__
#define __ardour_dialog_h__
-#include "ardour/ardour.h"
#include <gtkmm/window.h>
#include <gtkmm/dialog.h>
+#include "ardour/ardour.h"
+#include "ardour/session_handle.h"
+
namespace ARDOUR {
class Session;
}
/*
* This virtual parent class is so that each dialog box uses the
* same mechanism to declare its closing, and to have a common
* method of connecting and disconnecting from a Session.
*/
-class ArdourDialog : public Gtk::Dialog
+class ArdourDialog : public Gtk::Dialog, public ARDOUR::SessionHandlePtr
{
public:
ArdourDialog (std::string title, bool modal = false, bool use_separator = false);
@@ -48,16 +51,6 @@ class ArdourDialog : public Gtk::Dialog
void on_unmap ();
void on_show ();
- ARDOUR::Session *session;
-
- virtual void set_session (ARDOUR::Session* s) {
- session = s;
- }
-
- virtual void session_gone () {
- set_session (0);
- }
-
static void close_all_dialogs () { CloseAllDialogs(); }
private:
@@ -20,20 +20,23 @@
/*
* This virtual parent class is so that each dialog box uses the
- * same mechanism to declare its closing, and to have a common
- * method of connecting and disconnecting from a Session.
+ * same mechanism to declare its closing. It shares a common
+ * method of connecting and disconnecting from a Session with
+ * all other objects that have a handle on a Session.
*/